==> flutter_mylibrary-0.1.92.tar.gz: lib/http/exception/http_error.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/config/const.dart';


/// @desc  网络请求全局通知
/// @time 2019/3/20 10:02 AM
/// @author Cheney
class HttpError implements Exception {
  ///HTTP 状态码
  static const int UNAUTHORIZED = 401;
  static const int FORBIDDEN = 403;
  static const int NOT_FOUND = 404;
  static const int REQUEST_TIMEOUT = 408;
  static const int INTERNAL_SERVER_ERROR = 500;
  static const int BAD_GATEWAY = 502;
  static const int SERVICE_UNAVAILABLE = 503;
  static const int GATEWAY_TIMEOUT = 504;

  ///未知错误
  static const String UNKNOWN = "UNKNOWN";

  ///解析错误
  static const String PARSE_ERROR = "PARSE_ERROR";

  ///网络错误
  static const String NETWORK_ERROR = "NETWORK_ERROR";

  ///协议错误
  static const String HTTP_ERROR = "HTTP_ERROR";

  ///证书错误
  static const String SSL_ERROR = "SSL_ERROR";

  ///连接超时
  static const String CONNECT_TIMEOUT = "CONNECT_TIMEOUT";

  ///响应超时
  static const String RECEIVE_TIMEOUT = "RECEIVE_TIMEOUT";

  ///发送超时
  static const String SEND_TIMEOUT = "SEND_TIMEOUT";

  ///网络请求取消
  static const String CANCEL = "CANCEL";

  String code;

  String message;

  String url;

  DioError dioError;

  HttpError(this.code, this.message, {this.url});


  HttpError.dioError(DioError error) {
    this.dioError = error;
    message = error.message;
    switch (error.type) {
      case DioErrorType.CONNECT_TIMEOUT:
        code = CONNECT_TIMEOUT;
        message = CONNECT_TIMEOUT_MSG;
        break;
      case DioErrorType.RECEIVE_TIMEOUT:
        code = RECEIVE_TIMEOUT;
        message = RECEIVE_TIMEOUT_MSG;
        break;
      case DioErrorType.SEND_TIMEOUT:
        code = SEND_TIMEOUT;
        message = SEND_TIMEOUT_MSG;
        break;
      case DioErrorType.RESPONSE:
        code = HTTP_ERROR;
        message = HTTP_ERROR_MSG;
        break;
      case DioErrorType.CANCEL:
        code = CANCEL;
        message = CANCEL_MSG;
        break;
      case DioErrorType.DEFAULT:
        code = UNKNOWN;
        message = UNKNOWN_MSG;
        break;
    }
  }

  @override
  String toString() {
    return 'HttpError{code: $code, message: $message}';
  }

}

==> flutter_mylibrary-0.2.4.tar.gz: lib/http/exception/http_error.dart <==
import 'package:dio/dio.dart';
import 'package:flutter_mylibrary/config/const.dart';


/// @desc  网络请求全局通知
/// @time 2019/3/20 10:02 AM
/// @author Cheney
class HttpError implements Exception {
  ///HTTP 状态码
  static const int UNAUTHORIZED = 401;
  static const int FORBIDDEN = 403;
  static const int NOT_FOUND = 404;
  static const int REQUEST_TIMEOUT = 408;
  static const int INTERNAL_SERVER_ERROR = 500;
  static const int BAD_GATEWAY = 502;
  static const int SERVICE_UNAVAILABLE = 503;
  static const int GATEWAY_TIMEOUT = 504;

  ///未知错误
  static const String UNKNOWN = "UNKNOWN";

  ///解析错误
  static const String PARSE_ERROR = "PARSE_ERROR";

  ///网络错误
  static const String NETWORK_ERROR = "NETWORK_ERROR";

  ///协议错误
  static const String HTTP_ERROR = "HTTP_ERROR";

  ///证书错误
  static const String SSL_ERROR = "SSL_ERROR";

  ///连接超时
  static const String CONNECT_TIMEOUT = "CONNECT_TIMEOUT";

  ///响应超时
  static const String RECEIVE_TIMEOUT = "RECEIVE_TIMEOUT";

  ///发送超时
  static const String SEND_TIMEOUT = "SEND_TIMEOUT";

  ///网络请求取消
  static const String CANCEL = "CANCEL";

  String code;

  String message;

  String url;

  DioError dioError;

  HttpError(this.code, this.message, {this.url});


  HttpError.dioError(DioError error, s) {
    this.dioError = error;
    message = error.message;
    switch (error.type) {
      case DioErrorType.CONNECT_TIMEOUT:
        code = CONNECT_TIMEOUT;
        message = CONNECT_TIMEOUT_MSG;
        break;
      case DioErrorType.RECEIVE_TIMEOUT:
        code = RECEIVE_TIMEOUT;
        message = RECEIVE_TIMEOUT_MSG;
        break;
      case DioErrorType.SEND_TIMEOUT:
        code = SEND_TIMEOUT;
        message = SEND_TIMEOUT_MSG;
        break;
      case DioErrorType.RESPONSE:
        code = HTTP_ERROR;
        message = HTTP_ERROR_MSG;
        break;
      case DioErrorType.CANCEL:
        code = CANCEL;
        message = CANCEL_MSG;
        break;
      case DioErrorType.DEFAULT:
        code = UNKNOWN;
        message = s.toString();
        break;
    }
  }

  @override
  String toString() {
    return 'HttpError{code: $code, message: $message}';
  }

}
